# μEditor

[![PyPI - Version](https://img.shields.io/pypi/v/uedition-editor.svg)](https://pypi.org/project/uedition-editor)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/uedition-editor.svg)](https://pypi.org/project/uedition-editor)
[![Test workflow status](https://github.com/uEdition/uEditor/actions/workflows/tests.yml/badge.svg)](https://github.com/uEdition/uEditor/actions/workflows/tests.yml)
[![Test coverage](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/scmmmh/5e5b6cc511c2b9d625cba7bf9857a820/raw/coverage.json)](https://github.com/uEdition/uEditor/actions/workflows/tests.yml)

---

**Table of Contents**

- [Installation](#installation)
- [Documentation](#documentation)
- [License](#license)

## Installation

The simplest way to install the μEditor is using [pipx](https://github.com/pypa/pipx). Install pipx for your
operating system and then run the following command to install the μEditor:

```console
pipx install "uedition-editor>=2.0.0b2,<3"
```

Then run the following command to start the μEditor:

```console
UEDITOR__BASE_DIR=path/to/where/your/files/are ueditor server
```

The μEditor is then available at http://localhost:8000.

## Documentation

Documentation to come soon.

## License

`ueditor` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
